jQuery(document).ready(function ($) {
  'use strict';

  const FIELD_NAME = 'wil-list-terms';
  const CONTROL_NAME = WilokeBusinessHours.prefix + FIELD_NAME;

  async function createSelect2($el, initialData = [], taxonomy, action) {
    if ($el.hasClass('select2-hidden-accessible')) {
      $el.select2('destroy');
    }
    $el.select2({
      data: initialData,
      ajax: {
        url: ajaxurl,
        dataType: 'json',
        data(params) {
          return {
            q: params.term, // search term
            page: params.page,
            taxonomy,
            action,
          };
        },
        processResults(data, params) {
          params.page = params.page || 1;
          return {
            results: data,
            pagination: {
              more: params.page * 30 < data.length,
            },
          };
        },
      },
    });
  }

  function getSelect2Value($el) {
    return $el.select2('data').map(({ id, text }) => ({ id, text, selected: true }));
  }

  const postSelectControl = elementor.modules.controls.BaseData.extend({
    onReady() {
      this.taxonomy = 'category';
      this.registerDomSelector();
      this.fieldInitial();
      this.bindFieldChange();
      this.setStyles();
    },

    onBeforeDestroy() {
      if (this.$categories && this.$categories.select2) {
        this.$categories.select2('destroy');
      }
    },

    setStyles() {
      const styles = `
            .wil-width-100 {
                width:100%;
            }
            .wil-mb-15 {
                margin-bottom: 15px !important;
            }
          `;
      const id = 'wil-internal-style';
      const el = document.getElementById(id);
      if (el) {
        return;
      }
      const style = document.createElement('style');
      style.id = id;
      style.innerHTML = styles;
      document.head.appendChild(style);
    },

    registerDomSelector() {
      this.$categories = this.$el.find('.wil-categories-ids');
      this.$catNumber = this.$el.find('.wil-number-of-items');
      this.$taxonomy = this.$el.find('.wil-taxonomy');
      this.$hideEmpty = this.$el.find('.wil-hide-empty');
      this.$orderBy = this.$el.find('.wil-order-by');
      this.$order = this.$el.find('.wil-order');
      this.$postType = this.$el.find('.wil-post-type');
    },

    fieldInitial() {
      const settings = this.getCurrentValue();
      if (!settings) {
        return;
      }
      this.categoriesSelect(settings.categories);
      this.$catNumber.val(settings.limit);
      this.$hideEmpty.val(settings.hideEmpty);
      this.$taxonomy.val(settings.taxonomy);
      this.$order.val(settings.order);
      this.$orderBy.val(settings.orderBy);
      this.$postType.val(settings.postType);
      this.taxonomy = settings.taxonomy;

      if (!settings.enablePostType) {
        this.$postType.closest('.elementor-control-field').hide();
      }
    },

    bindFieldChange() {
      this.$categories.on('change', this.saveValue.bind(this));
      this.$catNumber.on('change', this.saveValue.bind(this));
      this.$orderBy.on('change', this.saveValue.bind(this));
      this.$order.on('change', this.saveValue.bind(this));
      this.$hideEmpty.on('change', this.saveValue.bind(this));
      this.$taxonomy.on('change', this.saveValue.bind(this));
      this.$postType.on('change', this.saveValue.bind(this));
    },

    saveValue() {
      this.setValue({
        limit: this.$catNumber.val(),
        categories: getSelect2Value(this.$categories),
        hideEmpty: this.$hideEmpty.val(),
        taxonomy: this.$taxonomy.val(),
        order: this.$order.val(),
        orderBy: this.$orderBy.val(),
        postType: this.$postType.val(),
        FIELD_NAME,
      });
      this.taxonomy = this.$taxonomy.val();
      this.categoriesSelect(getSelect2Value(this.$categories));
    },

    categoriesSelect(initialData = []) {
      createSelect2(this.$categories, initialData, this.taxonomy, WilokeBusinessHours.prefix + '_find_terms');
    },
  });

  elementor.addControlView(CONTROL_NAME, postSelectControl);
});