<?php

namespace WilokeBusinessHours\Controllers\SelectTaxonomyControl;

use Elementor\Base_Control;
use WilokeBusinessHours\Share\PostTypeHelper;
use WilokeBusinessHours\Share\TaxonomyHelper;
use WilokeBusinessHours\Share\TraitHandleCustomPost;

class SelectTaxonomyControl extends Base_Control
{
  use TraitHandleCustomPost;


  public function getFieldsOrderBy(): array
  {
    return [
      'name'    => esc_attr__('Name', 'wiloke-business-hours'),
      'count'   => esc_attr__('Number of children', 'wiloke-business-hours'),
      'term_id' => esc_attr__('Exactly what I entered', 'wiloke-business-hours')
    ];
  }

  public function getFieldsOrder(): array
  {
    return [
      'desc' => esc_attr__('DESC', 'wiloke-business-hours'),
      'asc'  => esc_attr__('ASC', 'wiloke-business-hours')
    ];
  }

  public function getTaxonomyOptions(): array
  {
    return TaxonomyHelper::getTaxonomyOptions();
  }

  public function get_type()
  {
    return WILOKE_WILOKEBUSINESSHOURS_NAMESPACE . 'wil-list-terms';
  }

  public function enqueue()
  {
    wp_register_script(WILOKE_WILOKEBUSINESSHOURS_NAMESPACE .
      '_custom_select_taxonomy_control',
      WILOKE_WILOKEBUSINESSHOURS_VIEWS_URL . 'src/Controllers/SelectTaxonomyControl/SelectTaxonomyControl.js',
      ['jquery'],
      WILOKE_WILOKEBUSINESSHOURS_VERSION,
      true);
    wp_localize_script('jquery', 'WilokeBusinessHours', [
      'prefix' => WILOKE_WILOKEBUSINESSHOURS_NAMESPACE
    ]);
    wp_enqueue_script(WILOKE_WILOKEBUSINESSHOURS_NAMESPACE .
      '_custom_select_taxonomy_control');
  }

  public function content_template()
  {
    ?>

    <div class="elementor-control elementor-control-type-divider elementor-control-separator-before"></div>

    <div class="wil-mb-15">
      <label class="elementor-control-title">{{{data.label }}}</label>

      <# if ( data.description ) { #>
      <div class="elementor-control-field-description">{{{data.description}}}
      </div>
      <# } #>
    </div>

    <div class="elementor-control-field wil-mb-15">

      <label
        class="elementor-control-title"><?php echo esc_html__('Number of items',
          'wiloke-business-hours'); ?>
      </label>

      <div class="elementor-control-input-wrapper elementor-control-unit-5">
        <input class="wil-number-of-items"
               type="number"
               min="0"
               name="limit"
        />
      </div>
    </div>

    <div class="elementor-control-field wil-mb-15">

      <label class="elementor-control-title"><?php echo esc_html__('Hide Empty?',
          'wiloke-business-hours'); ?></label>

      <div class="elementor-control-input-wrapper elementor-control-unit-5">
        <select name="wil-hide-empty"
                class="wil-hide-empty wil-width-100">
          <option value="1">
            <?php esc_html_e('Yes', 'wiloke-business-hours'); ?>
          </option>
          <option value="0">
            <?php esc_html_e('No', 'wiloke-business-hours'); ?>
          </option>
        </select>
      </div>
    </div>

    <div class="elementor-control-field wil-mb-15">

      <label class="elementor-control-title"><?php echo esc_html__('Order By',
          'wiloke-business-hours'); ?></label>

      <div class="elementor-control-input-wrapper elementor-control-unit-5">
        <select id="wil-cat-order-by" name="wil-cat-order-by"
                class="wil-cat-order-by wil-width-100 wil-order-by">
          <?php foreach ($this->getFieldsOrderBy() as $key => $value): ?>
            <option value="<?php echo esc_attr($key); ?>">
              <?php echo esc_html($value); ?>
            </option>
          <?php endforeach; ?>
        </select>
      </div>
    </div>

    <div class="elementor-control-field wil-mb-15">

      <label class="elementor-control-title"><?php echo esc_html__('Order',
          'wiloke-business-hours'); ?></label>

      <div class="elementor-control-input-wrapper elementor-control-unit-5">
        <select id="wil-cat-order" name="wil-cat-order"
                class="wil-cat-order wil-order wil-width-100">
          <?php foreach ($this->getFieldsOrder() as $key => $value): ?>
            <option value="<?php echo esc_attr($key); ?>">
              <?php echo esc_html($value); ?>
            </option>
          <?php endforeach; ?>
        </select>
      </div>
    </div>

    <div class="elementor-control-field wil-mb-15">

      <label
        class="elementor-control-title">
        <?php echo esc_html__('Taxonomy Key', 'wiloke-business-hours'); ?></label>

      <div class="elementor-control-input-wrapper elementor-control-unit-5">
        <select name="wil-taxonomy"
                class="wil-taxonomy wil-width-100">
          <?php foreach ($this->getTaxonomyOptions() as $key => $value): ?>
            <option value="<?php echo esc_attr($key); ?>">
              <?php echo esc_html($value); ?>
            </option>
          <?php endforeach; ?>
        </select>
      </div>
    </div>

    <div class="elementor-control-field wil-mb-15">
      <label class="elementor-control-title"><?php echo esc_html__('Specified Items',
          'wiloke-business-hours') ?></label>
      <div class="elementor-control-input-wrapper elementor-control-unit-5">
        <select multiple class="wil-categories-ids wil-width-100"
                name="wil-categories<?php echo uniqid(); ?>">
        </select>
      </div>
    </div>

    <div class="elementor-control-field wil-mb-15">

      <label class="elementor-control-title">
        <?php echo esc_html__('Main Post Type', 'wiloke-business-hours'); ?>
      </label>

      <div class="elementor-control-input-wrapper elementor-control-unit-5">
        <select name="wil-post-type"
                class="wil-post-type wil-width-100">
          <?php foreach (PostTypeHelper::getOptions() as $key => $value): ?>
            <option value="<?php echo esc_attr($key); ?>">
              <?php echo esc_html($value); ?>
            </option>
          <?php endforeach; ?>
        </select>
      </div>
    </div>

    <div
      class="elementor-control elementor-control-type-divider elementor-control-separator-after"></div>
    <?php

  }
}